<?php
namespace PriorityOneMarketingGroup;

class Clients {
    /**
     * @param object $conn
     * @param string $action
     * @param int $key
     * @param array $params
     */
    public function __construct($conn = null, $method = "", $action = null, $key = null, $values= array(), $params = array())
    {
        $this->mysql_connection = $conn;
        $this->key = $key;
        $this->params = $params;
        $this->method = $method;
        $this->values = $values;

        switch ($action) {
            case 'all':
                $this->results = self::getAllClients();
                break;

            case 'list':
                $this->results = self::getClientList();
                break;

            case 'client':
                if($this->method == 'GET')
                    $this->results = self::getClient();

                if($this->method == 'POST')
                    $this->results = self::createClient();

                if($this->method == 'PUT')
                    $this->results = self::updateClient();

                if($this->method == 'DELETE')
                    $this->results = self::deleteClient();

                break;

            case 'confirmation':
                $this->results = self::createConfirmation();
                break;

            case 'search':
                $this->results = self::searchClients();
                break;

            case 'projects':
                $this->results = self::getProjects();
                break;

            case 'rearrange':
                $this->results = self::rearrangeClientProjects();
                break;

            case 'total':
                $this->results = self::getTotalClients();
                break;

            case 'banner':
                $this->results = self::checkForBanner();
                break;

            case 'deleteProject':
                $this->results = self::removeProject();
                break;
        }
    }

    public function getResults(){
        $return = self::createJSON($this->results);

        return $return;
    }

    private function getTotalClients(){
        $total = $this->mysql_connection->select("SELECT COUNT(*) AS total FROM clients");

        $return[0]['total'] = $total[0]->total;

        return $return;
    }

    private function getAllClients(){
        $return = $this->mysql_connection->select("SELECT * FROM clients");

        return $return;
    }

    private function checkForBanner(){
        $projectID = $this->params['projectID'];

        if($this->key == 0){
            $check = $this->mysql_connection->select("SELECT p.title FROM clientProjects cp LEFT JOIN projects p ON p.id = cp.projectID WHERE cp.size = 'Banner' AND cp.projectID = $projectID");
        }else{
            $check = $this->mysql_connection->select("SELECT p.title FROM clientProjects cp LEFT JOIN projects p ON p.id = cp.projectID WHERE cp.size = 'Banner' AND cp.projectID = $projectID AND clientID != $this->key");
        }

        if(count($check) > 0){
            $return[0]['success'] = TRUE;
            $return[0]['project'] = $check[0]->title;
        }else{
            $return[0]['success'] = FALSE;
        }

        return $return;
    }

    private function getClientList(){
        $sql .= "SELECT id, name, contact, email FROM clients";

        if(isset($this->params['sortBy']) && isset($this->params['dir']) && $this->params['sortBy'] != 'project'){
            $sql .= " ORDER BY ".$this->params['sortBy']." ".$this->params['dir'];
        }else{
            $sql .= " ORDER BY id DESC";
        }

        if(isset($this->params['offset']) && isset($this->params['total'])){
            $start = $this->params['offset'];
            $total = ($start + $this->params['total']);
        }else{
            $start = 0;
            $total = 100;
        }

        $sql .= " LIMIT $start, $total";


        $return = $this->mysql_connection->select($sql);

        for ($i=0; $i < count($return); $i++) {
            $sql = 'SELECT p.title FROM clientProjects c LEFT JOIN projects p ON p.id = c.projectID WHERE c.clientID ='.$return[$i]->id." ORDER BY c.id DESC LIMIT 1";

            $project = $this->mysql_connection->select($sql);

            $return[$i]->project = $project[0]->title;
        }

        if(isset($this->params['sortBy']) && $this->params['sortBy'] == 'project'){
            usort($return, function($a, $b) {
                if($this->params['dir'] == 'ASC'){
                    return $a->project <=> $b->project;
                }else{
                    return $b->project <=> $a->project;
                }
            });
        }

        return $return;
    }

    private function getClient(){
        $return = $this->mysql_connection->select("SELECT * FROM clients WHERE id = $this->key");

        $projects = $this->mysql_connection->select("SELECT * FROM clientProjects WHERE clientID = $this->key ORDER BY id");

        $return[0]->projects = $projects;

        return $return;
    }

    private function deleteClient(){
        $this->mysql_connection->delete("DELETE FROM clients WHERE id=$this->key");
        $this->mysql_connection->delete("DELETE FROM clientProjects WHERE clientID=$this->key");

        $return[0]['success'] = TRUE;

        return $return;
    }

    private function removeProject(){
        $this->mysql_connection->delete("DELETE FROM clientProjects WHERE id=$this->key");

        $return[0]['success'] = TRUE;

        return $return;
    }

    private function updateClient(){
        extract($this->values);

        $name = $this->mysql_connection->real_escape_string($name);
        $contact = $this->mysql_connection->real_escape_string($contact);
        $contact2 = $this->mysql_connection->real_escape_string($contact2);
        $same = ($same) ? (int)$same : 0;


        $this->mysql_connection->update("UPDATE clients SET name='$name', contact='$contact', contact2='$contact2', invoice='$invoice',address1='$address1', address2='$address2', city='$city', state='$state', email='$email', phone1='$phone1', phone2='$phone2', fax='$fax', email2='$email2', website='$website', zip='$zip', shipadd1='$shipadd1', shipadd2='$shipadd2', shipcity='$shipcity', shipstate='$shipstate', shipzip='$shipzip', same='$same', rep='$rep' WHERE id=$this->key");

        $this->mysql_connection->delete("DELETE FROM clientProjects WHERE clientID=$this->key");

        for ($i=0; $i < count($projects); $i++) {
            $projectID = $projects[$i]["projectID"];
            $size = $projects[$i]["size"];
            $category = $this->mysql_connection->real_escape_string($projects[$i]["category"]);
            $cc = $projects[$i]["cc"];
            $amount = $projects[$i]["amount"];
            $total = $projects[$i]["total"];
            $processed = $projects[$i]["processed"];
            $type = $projects[$i]["type"];
            $signed = $projects[$i]["signed"];
            $signedNote = $this->mysql_connection->real_escape_string($projects[$i]["signedNote"]);
            $approved = $projects[$i]["approved"];
            $requests = $this->mysql_connection->real_escape_string($projects[$i]["requests"]);
            $subscribe = $projects[$i]["subscribe"];

            $this->mysql_connection->insert("INSERT INTO clientProjects (projectID, clientID, size, category, cc, amount, total, processed, type, rep, signedNote, approved, requests, subscribe) VALUES ('$projectID', '$this->key', '$size', '$category', '$cc', '$amount', '$total', '$processed', '$type', '$rep', '$signedNote', '$approved', '$requests', '$subscribe')");
        }

        $return[0]['success'] = TRUE;
        $return[0]['id'] = $this->key;

        return $return;
    }

    private function createClient(){
        extract($this->values);

        $name = $this->mysql_connection->real_escape_string($name);
        $contact = $this->mysql_connection->real_escape_string($contact);
        $contact2 = $this->mysql_connection->real_escape_string($contact2);
        $same = ($same) ? (int)$same : 0;

        $this->mysql_connection->insert("INSERT INTO clients (name, contact, contact2, invoice, address1, address2, city, state, email, phone1, phone2, fax, email2, website, requests, notes, zip, shipadd1, shipadd2, shipcity, shipstate, shipzip, same, rep) VALUES ('$name', '$contact', '$contact2', '$invoice', '$address1', '$address2', '$city', '$state', '$email', '$phone1', '$phone2', '$fax', '$email2', '$website', '$requests', '$notes', '$zip', '$shipadd1', '$shipadd2', '$shipcity', '$shipstate', '$shipzip', '$same', '$rep')");

        $id = $this->mysql_connection->getLastID();

        for ($i=0; $i < count($projects); $i++) {
            $projectID = $projects[$i]["projectID"];
            $size = $projects[$i]["size"];
            $category = $this->mysql_connection->real_escape_string($projects[$i]["category"]);
            $cc = $projects[$i]["cc"];
            $amount = $projects[$i]["amount"];
            $total = $projects[$i]["total"];
            $processed = $projects[$i]["processed"];
            $type = $projects[$i]["type"];
            $signed = $projects[$i]["signed"];
            $date = date("m/d/y");
            $signedNote = $this->mysql_connection->real_escape_string($projects[$i]["signedNote"]);
            $approved = $projects[$i]["approved"];
            $requests = $this->mysql_connection->real_escape_string($projects[$i]["requests"]);
            $subscribe = $projects[$i]["subscribe"];

            $this->mysql_connection->insert("INSERT INTO clientProjects (projectID, clientID, size, category, cc, amount, total, processed, type, rep, signedNote, approved, requests, subscribe, date) VALUES ('$projectID', '$id', '$size', '$category', '$cc', '$amount', '$total', '$processed', '$type', '$rep', '$signedNote', '$approved', '$requests', '$subscribe', '$date')");
        }

        $return[0]['success'] = TRUE;
        $return[0]['id'] = $id;

        return $return;
    }

    private function getProjects(){
        $return = $this->mysql_connection->select("SELECT * FROM clientProjects WHERE clientID = $this->key");

        return $return;
    }

    private function searchClients(){
        if(isset($this->params['keyphrase'])){
            $searchTerm = $this->mysql_connection->real_escape_string(urldecode($this->params['keyphrase']));
        }else{
            $searchTerm = '';
        }

        $i = 0;

        $names = $this->mysql_connection->select("SELECT id, name, contact, email FROM clients WHERE name LIKE '%$searchTerm%'");

        for ($j=0; $j < count($names); $j++) {
            $sql = 'SELECT p.title FROM clientProjects c LEFT JOIN projects p ON p.id = c.projectID WHERE c.clientID ='.$names[$j]->id." ORDER BY c.id DESC LIMIT 1";

            $project = $this->mysql_connection->select($sql);

            $names[$j]->project = $project[0]->title;
        }

        $return[$i]["name"] = "Names";
        $return[$i]["entries"] = $names;

        $i++;

        $contacts = $this->mysql_connection->select("SELECT id, name, contact, email FROM clients WHERE contact LIKE '%$searchTerm%' OR contact2 LIKE '%$searchTerm%'");

        for ($j=0; $j < count($contacts); $j++) {
            $sql = 'SELECT p.title FROM clientProjects c LEFT JOIN projects p ON p.id = c.projectID WHERE c.clientID ='.$contacts[$j]->id." ORDER BY c.id DESC LIMIT 1";

            $project = $this->mysql_connection->select($sql);

            $contacts[$j]->project = $project[0]->title;
        }

        $return[$i]["name"] = "Contacts";
        $return[$i]["entries"] = $contacts;

        $i++;

        $phones = $this->mysql_connection->select("SELECT id, name, contact, email FROM clients WHERE phone1 LIKE '%$searchTerm%' OR phone2 LIKE '%$searchTerm%'");

        for ($j=0; $j < count($phones); $j++) {
            $sql = 'SELECT p.title FROM clientProjects c LEFT JOIN projects p ON p.id = c.projectID WHERE c.clientID ='.$phones[$j]->id." ORDER BY c.id DESC LIMIT 1";

            $project = $this->mysql_connection->select($sql);

            $phones[$j]->project = $project[0]->title;
        }

        $return[$i]["name"] = "Phone";
        $return[$i]["entries"] = $phones;

        $i++;

        $ccs = $this->mysql_connection->select("SELECT id, name, contact, email FROM clients WHERE cc LIKE '%$searchTerm%'");

        for ($j=0; $j < count($ccs); $j++) {
            $sql = 'SELECT p.title FROM clientProjects c LEFT JOIN projects p ON p.id = c.projectID WHERE c.clientID ='.$ccs[$j]->id." ORDER BY c.id DESC LIMIT 1";

            $project = $this->mysql_connection->select($sql);

            $ccs[$j]->project = $project[0]->title;
        }

        $return[$i]["name"] = "Credit Card";
        $return[$i]["entries"] = $ccs;

        $i++;

        $emails = $this->mysql_connection->select("SELECT id, name, contact, email FROM clients WHERE email LIKE '%$searchTerm%' OR email2 LIKE '%$searchTerm%'");

        for ($j=0; $j < count($emails); $j++) {
            $sql = 'SELECT p.title FROM clientProjects c LEFT JOIN projects p ON p.id = c.projectID WHERE c.clientID ='.$emails[$j]->id." ORDER BY c.id DESC LIMIT 1";

            $project = $this->mysql_connection->select($sql);

            $emails[$j]->project = $project[0]->title;
        }

        $return[$i]["name"] = "Emails";
        $return[$i]["entries"] = $emails;

        $i++;

        /*$projects = $this->mysql_connection->select("SELECT c.id, c.name, c.contact, c.email, p.title AS project FROM projects p JOIN clientProjects cp ON cp.projectID = p.id JOIN clients c ON c.id = cp.clientID WHERE p.title LIKE '%$searchTerm%'");

        $return[$i]["name"] = "Projects";
        $return[$i]["entries"] = $projects;

        $i++;*/

        return $return;
    }

    private function createConfirmation(){
        if(isset($this->params['projectID'])){
            $projectID = urldecode($this->params['projectID']);
        }else{
            $projectID = '';
        }

        $client = $this->mysql_connection->select("SELECT * FROM clients WHERE id = $this->key");

        $project = $this->mysql_connection->select("SELECT cp.cc, cp.projectID, cp.requests, cp.total, cp.size, p.title, cp.category, cp.amount, cp.type, cp.processed FROM clientProjects cp LEFT JOIN projects p ON p.id = cp.projectID WHERE cp.clientID = $this->key AND cp.id = $projectID");

        $pID = $project[0]->projectID;

        $clubIDs = $this->mysql_connection->select("SELECT clubID FROM clubProjects WHERE projectID = $pID");

        $cids = "";

        for ($i=0; $i < count($clubIDs); $i++) {
            $cids .= "'".$clubIDs[$i]->clubID."'";

            if($i != count($clubIDs)-1){
                $cids .= ",";
            }
        }

        if($cids != ""){
            $clubs = $this->mysql_connection->select("SELECT name FROM clubs WHERE id IN ($cids)");
        }

        if(isset($this->params['text']) && $this->params['text'] == 'true'){
            $filename = dirname(__FILE__) . "/../../../public/files/confirmation_letters/".$this->clean($client[0]->name)."_".$this->clean($project[0]->title).".txt";
            $file = 'http://api.priorityonemarketinggroup.com/v1/public/files/confirmation_letters/'.$this->clean($client[0]->name)."_".$this->clean($project[0]->title).".txt";

            $output = '
'.$this->escapeString(date('m/d/Y')).''.PHP_EOL.'
'.$this->escapeString($client[0]->name).''.PHP_EOL.'
'.$this->escapeString($client[0]->address1).''.PHP_EOL.'
'.(($client[0]->address2 != "") ? '<span>'.$this->escapeString($client[0]->address2).'</span><br />' : '').''.PHP_EOL.'   
'.$this->escapeString($client[0]->city).', '.$this->escapeString($client[0]->state).' '.$this->escapeString($client[0]->zip).''.PHP_EOL.'
Dear '.$this->escapeString($client[0]->contact).','.PHP_EOL.'
We would like to take this opportunity to thank you for advertising in our business and service directory, \"'.$this->escapeString($project[0]->title).'\". This publication will be distributed to the following Golf and Country Clubs:'.PHP_EOL.'
                ';

                for ($i=0; $i < count($clubs); $i++) {
                    $output .= '
'.$this->escapeString($clubs[$i]->name).''.(($i != count($clubs)-1) ? ''.PHP_EOL.'' : '');
                }

                if(count($clubs) > 0){
                    $output .= '
'.PHP_EOL.'
                ';
                }

                $output .= '
Please know, your 12 months of advertising start on the date of delivery to the Country Clubs Pro Shops, not from date of purchase. Print dates vary due to advertisers approving their ad copy. A final copy of the edition will be mailed to you at the above stated address, as well as any other distribution locations The Golf Almanac deems appropriate.'.PHP_EOL.'
Website: www.thegolfalmanac.com<'.PHP_EOL.'
Please Email Ad Copy to our Graphics Department: gfx@thegolfalmanac.com'.PHP_EOL.'
Download Ad Specs at link below (this applies only if you choose to submit a finished ad)'.PHP_EOL.'
Ad Specs Link: http://www.thegolfalmanac.com/specs.html'.PHP_EOL.'
Some technical knowledge is required to use the design templates, and to save your work in the best format for print. Pre-designing advertisements is something we only recommend to those very comfortable with graphics applications.'.PHP_EOL.'
I, '.$this->escapeString($client[0]->contact).' of '.$this->escapeString($client[0]->name).' authorize The Golf Almanac to place a '.$this->escapeString($project[0]->size).' Page Color Ad, for the one-time cost for the year of $'.$this->escapeString($project[0]->total).', ';
                
                if($project[0]->type != 'PIF'){
                    $output .= 'half payment of $'.$project[0]->amount;
                }

                $output .= ' charged with credit card ending in ***'.$this->escapeString($project[0]->cc).'. The ad will be listed under the following categorie(s):'.PHP_EOL.'
'.$this->escapeString($project[0]->category).''.PHP_EOL.'
Special Requests:'.PHP_EOL.'
'.$this->escapeString($project[0]->requests).''.PHP_EOL.'
Best Regards,'.PHP_EOL.'
'.$this->clean($client[0]->rep).''.PHP_EOL.'
The Golf Almanac'.PHP_EOL.'
Office: 561-637-4700'.PHP_EOL.'
Signature____________________________________________________________________________ Date_____________________'.PHP_EOL.'
The Golf Almanac assumes full responsibility for the publishing and distribution of The Golf Almanac. Our goal is to release the publication in a timely fashion. The Golf Almanac reserves the right to replace, change or add distribution points as deemed necessary. A digital version of your ad will be emailed to you upon ad copy approval. A finished copy of the physical magazine will be mailed to you at the above stated address at the same time the magazines are shipped to the clubs. Please note that print dates vary due to advertisers approving their ad copy for print. By signing this document  you the advertiser agrees and understands  all sales are final and no cancellations are accepted.
The Golf Almanac'.PHP_EOL.'
7682 North Federal Hwy., Suite 1, Boca Raton, FL 33487'.PHP_EOL.'
Phone: 877-266-1060 | Fax 561-443-6706 or 561-330-6909 | Email: info@thegolfalmanac.com'.PHP_EOL.'
Web - www.thegolfalmanac.com - Licensed in the State of Florida LIC# TC5480'.PHP_EOL.'
            ';
        }else{
            $filename = dirname(__FILE__) . "/../../../public/files/confirmation_letters/".$this->clean($client[0]->name)."_".$this->clean($project[0]->title).".pdf";
            $file = 'http://api.priorityonemarketinggroup.com/v1/public/files/confirmation_letters/'.$this->clean($client[0]->name)."_".$this->clean($project[0]->title).".pdf";

            $worddoc = '
                <html>

                    <head>
                    </head>

                    <body style="font-family:Times;font-size:12px;">
                        <div style="width:100%;text-align:center">
                            <img src="'.dirname(__FILE__) . '/../../../public/images/ga-logo.jpg" width="250" />
                        </div>
                        <div style="width:100%;text-align:center;font-size:10px;">
                            <span style="font-weight:bold;">'.$this->escapeString($project[0]->processed).'</span>
                        </div>
                        <div>
                            <span>'.$this->escapeString($client[0]->name).'</span><br />
                            <span>'.$this->escapeString($client[0]->address1).'</span><br />
                            '.(($client[0]->address2 != "") ? '<span>'.$this->escapeString($client[0]->address2).'</span><br />' : '').'      
                            <span>'.$this->escapeString($client[0]->city).', '.$this->escapeString($client[0]->state).' '.$this->escapeString($client[0]->zip).'</span>
                        </div>
                        <div>&nbsp;</div>
                        <div>Dear '.$this->escapeString($client[0]->contact).',</div>
                        <div>&nbsp;</div>
                        <div>
                            We would like to take this opportunity to thank you for advertising in our business and service directory, \"'.$this->escapeString($project[0]->title).'\". This publication will be distributed to the following Golf and Country Clubs:
                        </div>
                        <div>&nbsp;</div>
                        <div>
                ';

                for ($i=0; $i < count($clubs); $i++) {
                    $worddoc .= '
                            <span>'.$this->escapeString($clubs[$i]->name).'</span>'.(($i != count($clubs)-1) ? '<br />' : '');
                }

                $worddoc .= '
                        </div>
                        <div>&nbsp;</div>
                        <div>
                           Please know, your 12 months of advertising start on the date of delivery to the Country Clubs Pro Shops, not from date of purchase. Print dates vary due to advertisers approving their ad copy. A final copy of the edition will be mailed to you at the above-stated address, as well as any other distribution locations The Golf Almanac™ deems appropriate.
                        </div>
                        <div>&nbsp;</div>
                        <div>
                            <span>Website: www.thegolfalmanac.com</span><br />
                            <span>Please Email Ad Copy to our Graphics Department: gfx@thegolfalmanac.com</span><br />
                            <span>Download Ad Specs at link below (this applies only if you choose to submit a finished ad)</span><br />
                            <span>Ad Specs Link: Click <a href="http://www.thegolfalmanac.com/specs.html" target="_blank">Here</a> http://www.thegolfalmanac.com/specs.html </span><br />
                            <span>Some technical knowledge is required to use the design templates and to save your work in the best format for print. Pre-designing advertisements are something we only recommend to those very comfortable with graphics applications.</span>
                        </div>
                        <div>&nbsp;</div>
                        <div>
                            <span>
                                I, '.$this->escapeString($client[0]->contact).' of '.$this->escapeString($client[0]->name).' authorize The Golf Almanac™ to place a '.$this->escapeString($project[0]->size).' Page Color Ad, for the one-time cost for the year of $'.$this->escapeString($project[0]->total).', ';
                
                if($project[0]->type != 'PIF'){
                    $worddoc .= 'half payment of $'.$project[0]->amount;
                }

                $worddoc .= ' charged with credit card ending in ***'.$this->escapeString($project[0]->cc).'. The ad will be listed under the following categorie(s):
                            </span><br />
                            <span>'.$this->escapeString($project[0]->category).'</span>
                        </div>
                        <div>&nbsp;</div>
                        <div>
                            <span>Special Requests:</span><br />
                            <span>'.$this->escapeString($project[0]->requests).'</span>
                        </div>
                        <div>&nbsp;</div>
                        <div>
                            <span>Best Regards,</span><br />
                            <span>'.$this->clean($client[0]->rep).'</span><br />
                            <span>The Golf Almanac</span><br />
                            <span>Office: 561-637-4700</span>
                        </div>
                        <div>&nbsp;</div>
                        <div>
                            <span>Signature____________________________________________________________________________ Date_____________________</span><br />
                            <span style="font-family:Georgia;font-size:10px;">
                                The Golf Almanac™ assumes full responsibility for the publishing and distribution of The Golf Almanac™. Our goal is to release the publication in a timely fashion. The Golf Almanac™ reserves the right to replace, change or add distribution points as deemed necessary. A digital version of your ad will be emailed to you upon ad copy approval. A finished copy of the physical magazine will be mailed to you at the above-stated address at the same time the magazines are shipped to the clubs. Please note that print dates vary due to advertisers approving their ad copy for print. By signing this document you the advertiser agrees and understands all sales are final and no cancellations are accepted after seven days of purchase. If a written cancelation notice is given to us in writing within seven days of purchase you will be fully refunded within thirty days after written notice is given. Please send any notice to info@thegolfalmanac.com

                            </span>
                        </div>
                        <div>&nbsp;</div>
                        <div>&nbsp;</div>
                        <div style="font-family:Calibri;text-align:center;font-size:10px;">
                            <span>The Golf Almanac™</span><br />
                            <span>7682 North Federal Hwy., Suite 1, Boca Raton, FL 33487</span><br />
                            <span>Phone: 877-266-1060 | Fax 561-443-6706 or 561-330-6909 | Email: info@thegolfalmanac.com</span><br />
                            <span>Web - www.thegolfalmanac.com - Licensed in the State of Florida - LIC# TC5480</span>
                        </div>
                    </body>
                </html>
            ';

            $dompdf = new \Dompdf\Dompdf();
            $dompdf->load_html($worddoc);
            $dompdf->render();
            $output = $dompdf->output();
        }

        file_put_contents($filename, $output);

        $return[0]['success'] = true;
        $return[0]['file'] = $file;

        return $return;
    }

    private function escapeString($string){
        $string = str_replace("&", "and", $string);
        $string = str_replace("'", "\'", $string);
        $string = str_replace('"', '\"', $string);
        $string = str_replace(")", ". ", $string);

        return $string;
    }

    private function clean($string) {
       $string = str_replace(' ', '-', $string); // Replaces all spaces with hyphens.

       return preg_replace('/[^A-Za-z0-9\-]/', '', $string); // Removes special chars.
    }

    private function createJSON($results){
        for ($i=0;$i<count($results);$i++) {
            if(count($results) > 1 && $i == 0) $return .= '[';
            $return .= ($i>0?',':'').json_encode($results[$i]);
            if(count($results) > 1 && $i == (count($results)-1)) $return .= ']';
        }

        return $return;
    }

    private function rearrangeClientProjects(){
        $projects = $this->mysql_connection->select("
            SELECT p.id AS projectID, c.id AS clientID, c.cat1 AS category, c.size, c.cc, c.amount, c.total, c.processed, c.type, c.date, c.rep, c.signed, c.signedNote, c.approved, c.requests, c.subscribe
            FROM clients c
            JOIN projects p
            ON p.title = c.project1
            UNION
            SELECT p.id AS projectID, c.id AS clientID, c.cat1 AS category, c.size2 AS size, c.cc2 AS cc, c.amount2 AS amount, c.total2 AS total, c.processed2 AS processed, c.type2 AS type, c.date2 AS date, c.rep AS rep, c.signed2 AS signed, c.signedNote2 AS signedNote, c.approved2 AS approved, c.requests2 AS requests, c.subscribe2 AS subscribe
            FROM clients c
            JOIN projects p
            ON p.title = c.project2
            UNION
            SELECT p.id AS projectID, c.id AS clientID, c.cat1 AS category, c.size3 AS size, c.cc3 AS cc, c.amount3 AS amount, c.total3 AS total, c.processed3 AS processed, c.type3 AS type, c.date3 AS date, c.rep AS rep, c.signed3 AS signed, c.signedNote3 AS signedNote, c.approved3 AS approved, c.requests3 AS requests, c.subscribe3 AS subscribe
            FROM clients c
            JOIN projects p
            ON p.title = c.project3
            UNION
            SELECT p.id AS projectID, c.id AS clientID, c.cat1 AS category, c.size4 AS size, c.cc4 AS cc, c.amount4 AS amount, c.total4 AS total, c.processed4 AS processed, c.type4 AS type, c.date4 AS date, c.rep AS rep, c.signed4 AS signed, c.signedNote4 AS signedNote, c.approved4 AS approved, c.requests4 AS requests, c.subscribe4 AS subscribe
            FROM clients c
            JOIN projects p
            ON p.title = c.project4
            UNION
            SELECT p.id AS projectID, c.id AS clientID, c.cat1 AS category, c.size5 AS size, c.cc5 AS cc, c.amount5 AS amount, c.total5 AS total, c.processed5 AS processed, c.type5 AS type, c.date5 AS date, c.rep AS rep, c.signed5 AS signed, c.signedNote5 AS signedNote, c.approved5 AS approved, c.requests5 AS requests, c.subscribe5 AS subscribe
            FROM clients c
            JOIN projects p
            ON p.title = c.project5
        ");

        for ($i=0; $i < count($projects); $i++) {
            $clientID = $projects[$i]->clientID;
            $projectID = $projects[$i]->projectID;
            $size = $this->mysql_connection->escape_string($projects[$i]->size);
            $category = $this->mysql_connection->escape_string($projects[$i]->category);
            $cc = $this->mysql_connection->escape_string($projects[$i]->cc);
            $amount = $this->mysql_connection->escape_string($projects[$i]->amount);
            $total = $this->mysql_connection->escape_string($projects[$i]->total);
            $processed = $this->mysql_connection->escape_string($projects[$i]->processed);
            $type = $this->mysql_connection->escape_string($projects[$i]->type);
            $date = $this->mysql_connection->escape_string($projects[$i]->date);
            $rep = $this->mysql_connection->escape_string($projects[$i]->rep);
            $signed = $projects[$i]->signed;
            $signedNote = $this->mysql_connection->escape_string($projects[$i]->signedNote);
            $approved = $projects[$i]->approved;
            $requests = $this->mysql_connection->escape_string($projects[$i]->requests);
            $subscribe = $projects[$i]->subscribe;

            if($projectID != ''){
                $this->mysql_connection->insert("INSERT INTO clientProjects (clientID, projectID, size, category, cc, amount, total, processed, type, date, rep, signed, signedNote, approved, requests, subscribe) VALUES ($clientID, $projectID, '$size', '$category', '$cc', '$amount', '$total', '$processed', '$type', '$date', '$rep', $signed, '$signedNote', $approved, '$requests', $subscribe)");
            }
        }

        $return['success'] = TRUE;

        return $return;
    }
}

?>
