<?php
namespace PriorityOneMarketingGroup;

class Projects {
    /**
     * @param object $conn
     * @param string $action
     * @param int $key
     * @param array $params
     */
    public function __construct($conn = null, $method = null, $action = null, $key = null, $values = array(), $params = array())
    {
        $this->mysql_connection = $conn;
        $this->key = $key;
        $this->params = $params;
        $this->method = $method;
        $this->values = $values;

        switch ($action) {
            case 'all':
                $this->results = self::getAllProjects();
                break;

            case 'list':
                $this->results = self::getProjectList();
                break;

            case 'project':
                if($this->method == 'GET')
                    $this->results = self::getProject();

                if($this->method == 'POST')
                    $this->results = self::createProject();

                if($this->method == 'PUT')
                    $this->results = self::updateProject();

                if($this->method == 'DELETE')
                    $this->results = self::deleteProject();

                break;

            case 'approved':
                $this->results = self::getAllNotApproved();
                break;

            case 'clubs':
                $this->results = self::getAllClubs();
                break;

            case 'clients':
                $this->results = self::getAllClients();
                break;

            case 'dropdown':
                $this->results = self::getDropdownList();
                break;

            case 'search':
                $this->results = self::searchProjects();
                break;

            case 'runsheet':
                $this->results = self::createRunsheet();
                break;

            case 'contactList':
                $this->results = self::createContactList();
                break;

            case 'clientsSheet':
                $this->results = self::createClients();
                break;

            case 'clubsSheet':
                $this->results = self::createClubs();
                break;

            case 'emails':
                $this->results = self::createEmails();
                break;

            case 'total':
                $this->results = self::getTotalProjects();
        }
    }

    public function getResults(){
        $return = self::createJSON($this->results);

        return $return;
    }

    private function getAllProjects(){
        $return = $this->mysql_connection->select("SELECT * FROM projects");

        return $return;
    }

    private function getTotalProjects(){
        $total = $this->mysql_connection->select("SELECT COUNT(*) AS total FROM projects");

        $return[0]['total'] = $total[0]->total;

        return $return;
    }

    private function getProjectList(){
        $sql .= "SELECT id, title, open, start FROM projects";

        if(isset($this->params['sortBy']) && isset($this->params['dir'])){
            $sql .= " ORDER BY ".$this->params['sortBy']." ".$this->params['dir'];
        }else{
            $sql .= " ORDER BY id DESC";
        }

        if(isset($this->params['offset']) && isset($this->params['total'])){
            $start = $this->params['offset'];
            $total = ($start + $this->params['total']);
        }else{
            $start = 0;
            $total = 100;
        }

        $sql .= " LIMIT $start, $total";

        $return = $this->mysql_connection->select($sql);

        for ($i=0; $i < count($return); $i++) {
            $id = $return[$i]->id;

            $signed = $this->mysql_connection->select("SELECT count(*) AS total FROM clientProjects WHERE projectID = $id AND approved = 0");
            $amount = $this->mysql_connection->select("SELECT count(*) AS total FROM clientProjects WHERE projectID = $id");

            $return[$i]->total = $signed[0]->total;
            $return[$i]->amount = $amount[0]->total;
        }

        if(isset($this->params['sortBy']) && $this->params['sortBy'] == 'start' && isset($this->params['dir'])){
            if($this->params['dir'] == 'ASC'){
                usort($return, function ($item1, $item2) {
                    $date1 = date_create_from_format('d/m/Y', $item1->start);
                    $date2 = date_create_from_format('d/m/Y', $item2->start);
                    return $date1 <=> $date2;
                });
            }else{
                usort($return, function ($item1, $item2) {
                    $date1 = date_create_from_format('d/m/Y', $item1->start);
                    $date2 = date_create_from_format('d/m/Y', $item2->start);
                    return $date2 <=> $date1;
                });
            }
        }

        return $return;
    }

    private function getDropdownList(){
        $sql = "SELECT id, title FROM projects ORDER BY title ASC";

        $return = $this->mysql_connection->select($sql);

        return $return;
    }

    private function getProject(){
        $project = $this->mysql_connection->select("SELECT * FROM projects WHERE id = $this->key");

        $total = $this->mysql_connection->select("SELECT COUNT(*) AS total FROM clientProjects WHERE projectID = $this->key");

        $return = array();
        $return[0] = [
            'id' => $project[0]->id,
            'title' => $project[0]->title,
            'city' => $project[0]->city,
            'state' => $project[0]->state,
            'open' => $project[0]->open,
            'start' => $project[0]->start,
            'print' => $project[0]->print,
            'proof' => $project[0]->proof,
            'mailed' => $project[0]->mailed,
            'remailed' => $project[0]->remailed,
            'remailed2' => $project[0]->remailed2,
            'remailed3' => $project[0]->remailed3,
            'inventory' => $project[0]->inventory,
            'notes' => $project[0]->notes,
            'closed' => $project[0]->closed,
            'total' => $total[0]->total
        ];

        return $return;
    }

    private function deleteProject(){
        $this->mysql_connection->delete("DELETE FROM projects WHERE id=$this->key");
        $this->mysql_connection->delete("DELETE FROM clubProjects WHERE projectID=$this->key");

        $return[0]['success'] = TRUE;

        return $return;
    }

    private function updateProject(){
        extract($this->values);

        $this->mysql_connection->update("UPDATE projects SET title='$title', city='$city', state='$state', open='$open', start='$start', proof='$proof', print='$print', mailed='$mailed', remailed='$remailed', remailed2='$remailed2', remailed3='$remailed3', inventory='$inventory', notes='$notes', closed='$closed' WHERE id=$this->key");


        $return[0]['success'] = TRUE;
        $return[0]['id'] = $this->key;

        return $return;
    }

    private function createProject(){
        extract($this->values);
        
        $total = 0;

        $this->mysql_connection->insert("INSERT INTO projects (title, city, state, open, start, proof, print, mailed, remailed, remailed2, remailed3, inventory, notes, closed, total) VALUES ('$title', '$city', '$state', '$open', '$start', '$proof', '$print', '$mailed', '$remailed', '$remailed2', '$remailed3', '$inventory', '$notes', '$closed', '$total')");

        $return[0]['success'] = TRUE;
        $return[0]['id'] = $this->mysql_connection->getLastID();

        return $return;
    }

    private function getAllNotApproved(){
        $approved = $this->mysql_connection->select("SELECT c.id, c.name, c.contact, c.phone1, c.phone2, c.email FROM clients c LEFT JOIN clientProjects cp ON cp.clientID = c.id WHERE cp.projectID = $this->key AND cp.approved = 0");

        $return[0]['success'] = TRUE;
        $return[0]['approved'] = $approved;

        return $return;
    }

    private function getAllApprovedTotal(){
        $signed = $this->mysql_connection->select("SELECT count(*) AS total FROM clientProjects WHERE projectID = $this->key AND approved = 1");

        $return[0]['total'] = $signed[0]->total;

        return $return;
    }

    private function getAllClubs(){
        $return = $this->mysql_connection->select("SELECT c.id, c.name FROM clubProjects cp RIGHT JOIN clubs c ON c.id = cp.clubID WHERE projectID = $this->key");

        return $return;
    }

    private function getAllClients(){
        $return = $this->mysql_connection->select("SELECT c.id, c.name FROM clientProjects cp RIGHT JOIN clients c ON c.id = cp.clientID WHERE projectID = $this->key");

        return $return;
    }

    private function searchProjects(){
        if(isset($this->params['keyphrase'])){
            $searchTerm = urldecode($this->params['keyphrase']);
        }else{
            $searchTerm = '';
        }

        $i = 0;

        $titles = $this->mysql_connection->select("SELECT id, title, open, start FROM projects WHERE title LIKE '%$searchTerm%'");

        $return[$i]["name"] = "Titles";
        $return[$i]["entries"] = $titles;

        $i++;

        $cities = $this->mysql_connection->select("SELECT id, title, open, start FROM projects WHERE city LIKE '%$searchTerm%'");

        $return[$i]["name"] = "Cities";
        $return[$i]["entries"] = $cities;

        $i++;

        $states = $this->mysql_connection->select("SELECT id, title, open, start FROM projects WHERE state LIKE '%$searchTerm%'");
        
        $return[$i]["name"] = "States";
        $return[$i]["entries"] = $states;

        $i++;

        for ($j=0; $j < count($return); $j++) {
            for ($i=0; $i < count($return[$j]['entries']); $i++) {
                $id = $return[$j]['entries'][$i]->id;

                $signed = $this->mysql_connection->select("SELECT count(*) AS total FROM clientProjects WHERE projectID = $id AND approved = 1");
                $amount = $this->mysql_connection->select("SELECT count(*) AS total FROM clientProjects WHERE projectID = $id");

                $return[$j]['entries'][$i]->total = $signed[0]->total;
                $return[$j]['entries'][$i]->amount = $amount[0]->total;
            }
        }

        return $return;
    }

    private function createRunsheet(){
        $project = $this->mysql_connection->select("SELECT * FROM projects WHERE `id`='$this->key'");
        $proj = $project[0]->title;
        $proj_title = preg_replace("/[^A-Za-z0-9]/i", "", $proj);

        $clients = $this->mysql_connection->select("SELECT c.name, c.contact, c.shipadd1, c.shipadd2, c.shipcity, c.shipstate, c.shipzip, c.email, c.phone1, c.phone2, c.fax, cp.processed, c.rep, cp.amount, cp.size, cp.category, cp.requests, cp.signedNote FROM clientProjects cp LEFT JOIN clients c ON cp.clientID = c.id WHERE projectID = $this->key");

        $filename = dirname(__FILE__) . '/../../../public/files/runsheets/'.$proj_title."_".date('Y_m_d').".doc";
        
        $str .= "
            <html xmlns:office='urn:schemas-microsoft-com:office:office' xmlns:word='urn:schemas-microsoft-com:office:word' xmlns='http://www.w3.org/TR/REC-html40'>
                <head>
                    <META HTTP-EQUIV='Content-Type' CONTENT='text/html charset=UTF-8'>
                    <meta name=ProgId content=Word.Document>
                    <meta name=Generator content='Microsoft Word 9'>
                    <meta name=Originator content='Microsoft Word 9'>
                    <style>
                        @page Section1 {size:595.45pt 841.7pt; margin:1.0in 1.25in 1.0in 1.25in;mso-header-margin:.5in;mso-footer-margin:.5in;mso-paper-source:0;}
                            div.Section1 {page:Section1;}
                        @page Section2 {size:841.7pt 595.45pt;mso-page-orientation:landscape;margin:1.25in 1.0in 1.25in 1.0in;mso-header-margin:.5in;mso-footer-margin:.5in;mso-paper-source:0;}
                            div.Section2 {page:Section2;}
                    </style>
                </head>
                <body>
                    <div class=Section2>
                        <table cellpadding='5' border='1'>
                            <tr>
                                <td>Date</td>
                                <td>Sales Rep</td>
                                <td>Amount</td>
                                <td>Size</td>
                                <td>Category</td>
                                <td>Business Name/Contact</td>
                                <td>Email & Business Numbers</td>
                                <td>Special Requests</td>
                                <td>Notes</td>
                            </tr>
            ";   

            for ($i=0; $i < count($clients); $i++) {
                $str .='
                            <tr>
                                <td>'.$clients[$i]->processed.'</td>
                                <td>'.$clients[$i]->rep.'</td>
                                <td>'.$clients[$i]->amount.'</td>
                                <td>'.$clients[$i]->size.'</td>
                                <td>'.nl2br($clients[$i]->category).'</td>
                                <td>'.$clients[$i]->name.'<br />ATTN: '.$clients[$i]->contact.'<br />'.$clients[$i]->shipadd1.'<br />'.(($clients[$i]->shipadd2) ? $clients[$i]->shipadd2.'<br />' : '' ).$clients[$i]->shipcity.', '.$clients[$i]->shipstate.' '.$clients[$i]->shipzip.'</td>
                                <td>Email: '.$clients[$i]->email.'<br />Primary #: '.$clients[$i]->phone1.'<br />Secondary #: '.$clients[$i]->phone2.'<br />Fax: '.$clients[$i]->fax.'</td>
                                <td>'.$clients[$i]->requests.'</td>
                                <td>'.$clients[$i]->signedNote.'</td>
                            </tr>
                ';
            }

            $str .= "
                        </table>
                    </div>
                </body>
            </html>
        ";

        file_put_contents($filename, $str);

        $return[0]['success'] = true;
        $return[0]['file'] = 'http://api.priorityonemarketinggroup.com/v1/public/files/runsheets/'.$proj_title."_".date('Y_m_d').".doc";

        return $return;
    }

    private function createContactList(){
        $project = $this->mysql_connection->select("SELECT * FROM projects WHERE `id`='$this->key'");
        $proj = $project[0]->title;
        $proj_title = preg_replace("/[^A-Za-z0-9]/i", "", $proj);

        $clients = $this->mysql_connection->select("SELECT c.name, c.email, c.phone1, c.phone2, c.contact, c.shipadd1, c.shipadd2, c.shipcity, c.shipstate, c.shipzip, cp.size, cp.total FROM clientProjects cp LEFT JOIN clients c ON cp.clientID = c.id WHERE projectID = $this->key");
        $filename = dirname(__FILE__) . '/../../../public/files/contact_lists/'.$proj_title."_".date('Y_m_d').".csv";
        $fp = fopen($filename, 'w+');

        fputcsv($fp, array('Business Name', 'Email', 'Business Phone', 'Cell Phone', 'Contact Name', 'Street Line 1', 'Street Line 2', 'City', 'State', 'Zip', 'Size', 'Total'));

        for ($i=0; $i < count($clients); $i++) { 
            fputcsv( $fp,
                array(
                    $clients[$i]->name,
                    $clients[$i]->email,
                    $clients[$i]->phone1,
                    $clients[$i]->phone2,
                    $clients[$i]->contact,
                    $clients[$i]->shipadd1,
                    $clients[$i]->shipadd2,
                    $clients[$i]->shipcity,
                    $clients[$i]->shipstate,
                    $clients[$i]->shipzip,
                    $clients[$i]->size,
                    $clients[$i]->total
                )
            );
        }

        fclose($fp);

        $return[0]['success'] = true;
        $return[0]['file'] = 'http://api.priorityonemarketinggroup.com/v1/public/files/contact_lists/'.$proj_title."_".date('Y_m_d').".csv";

        return $return;   
    }

    private function createClients(){
        $project = $this->mysql_connection->select("SELECT * FROM projects WHERE `id`='$this->key'");
        $proj = $project[0]->title;
        $proj_title = preg_replace("/[^A-Za-z0-9]/i", "", $proj);

        $clients = $this->mysql_connection->select("SELECT c.name, c.contact, c.shipadd1, c.shipadd2, c.shipcity, c.shipstate, c.shipzip FROM clientProjects cp LEFT JOIN clients c ON cp.clientID = c.id WHERE projectID = $this->key");
        $filename = dirname(__FILE__) . '/../../../public/files/clients/'.$proj_title."_".date('Y_m_d').".csv";
        $fp = fopen($filename, 'w+');

        fputcsv($fp, array('Business Name', 'Contact Name', 'Street Line 1', 'Street Line 2', 'City', 'State', 'Zip'));

        for ($i=0; $i < count($clients); $i++) { 
            fputcsv( $fp,
                array(
                    $clients[$i]->name,
                    $clients[$i]->contact,
                    $clients[$i]->shipadd1,
                    $clients[$i]->shipadd2,
                    $clients[$i]->shipcity,
                    $clients[$i]->shipstate,
                    $clients[$i]->shipzip
                )
            );
        }

        fclose($fp);

        $return[0]['success'] = true;
        $return[0]['file'] = 'http://api.priorityonemarketinggroup.com/v1/public/files/clients/'.$proj_title."_".date('Y_m_d').".csv";

        return $return;   
    }

    private function createClubs(){
        $project = $this->mysql_connection->select("SELECT * FROM projects WHERE `id`='$this->key'");
        $proj = $project[0]->title;
        $proj_title = preg_replace("/[^A-Za-z0-9]/i", "", $proj);

        $clubs = $this->mysql_connection->select("SELECT c.name, c.contact, c.address1, c.address2, c.city, c.state, c.zip FROM clubProjects cp LEFT JOIN clubs c ON cp.clubID = c.id WHERE projectID = $this->key");
        $filename = dirname(__FILE__) . '/../../../public/files/clubs/'.$proj_title."_".date('Y_m_d').".doc";
        $fp = fopen($filename, 'w+');

        $j = 0;

        $str .= "
            <html>
                <body>
                <table>
                    ";
            for ($i=0; $i < count($clubs); $i++) {
                $str .='
                    '.(($j==0) ? '<tr style="width:800px;">' : '').'
                        <td style="width:390px;text-align:center;margin:0 10px 0 0;height:140px;font-size:14px;font-family:times;">
                            '.$clubs[$i]->name.'<br />
                            ATTN: '.$clubs[$i]->contact.'<br />
                            '.$clubs[$i]->address1.'
                            '.(($clubs[$i]->address2) ? '<br />'.$clubs[$i]->address2 : '' ).'<br />
                            '.$clubs[$i]->city.', '.$clubs[$i]->state.'  '.$clubs[$i]->zip.'
                        </td>
                    '.(($j==1) ? '</tr>' : '').'
                ';

                (($j==1) ? $j=0 : $j++);
            }

            (($j==1) ? $str .= '<td style="width:390px;text-align:center;margin:0 10px 0 0;height:140px;font-size:14px;font-family:times;">&nbsp;</td></tr>' : '');

            $str .= "
                </table>
                </body>
            </html>";

        fwrite($fp, $str);
        fclose($fp);

        $return[0]['success'] = true;
        $return[0]['file'] = 'http://api.priorityonemarketinggroup.com/v1/public/files/clubs/'.$proj_title."_".date('Y_m_d').".doc";

        return $return;   
    }

    private function createEmails(){
        $project = $this->mysql_connection->select("SELECT * FROM projects WHERE `id`='$this->key'");
        $proj = $project[0]->title;
        $proj_title = preg_replace("/[^A-Za-z0-9]/i", "", $proj);

        $clients = $this->mysql_connection->select("SELECT c.email FROM clientProjects cp LEFT JOIN clients c ON cp.clientID = c.id WHERE projectID = $this->key");
        $filename = dirname(__FILE__) . '/../../../public/files/emails/'.$proj_title."_".date('Y_m_d').".doc";
        $fp = fopen($filename, 'w+');

        $j = 0;

        $str .= "
            <html>
                <body>
                <table>
                    <tr>
                        <td>
                    ";
            for ($i=0; $i < count($clients); $i++) {
                $str .= $clients[$i]->email;
                if($i < count($clients)-1){
                    $str .= ', ';
                }
            }

            $str .= "
                        </td>
                    </tr>
                </table>
                </body>
            </html>";

        fwrite($fp, $str);
        fclose($fp);

        $return[0]['success'] = true;
        $return[0]['file'] = 'http://api.priorityonemarketinggroup.com/v1/public/files/emails/'.$proj_title."_".date('Y_m_d').".doc";

        return $return;   
    }

    private function createJSON($results){
        for ($i=0;$i<count($results);$i++) {
            if(count($results) > 1 && $i == 0) $return .= '[';
            $return .= ($i>0?',':'').json_encode($results[$i]);
            if(count($results) > 1 && $i == (count($results)-1)) $return .= ']';
        }

        return $return;
    }
}

?>